==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/General/lyrics/translations/lyrics_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Pokaż tekst piosenki</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka tekstów piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>O wtyczce Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Wtyczka Teksty Piosenek dla Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Ta wtyczka ściąga teksty piosenek z LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka wyszukiwania tekstów piosenek</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artysta:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Nie połączony</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>Nie znaleziono</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Teksty: %1 - %2</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/lyrics/translations/lyrics_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Pokaż tekst piosenki</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka tekstów piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>O wtyczce Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Wtyczka Teksty Piosenek dla Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Ta wtyczka ściąga teksty piosenek z LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka wyszukiwania tekstów piosenek</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="45"/>
        <source>Artist:</source>
        <translation>Artysta:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="55"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="65"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="36"/>
        <source>No connection</source>
        <translation>Nie połączony</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="76"/>
        <location filename="../lyricswindow.cpp" line="209"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="79"/>
        <location filename="../lyricswindow.cpp" line="103"/>
        <location filename="../lyricswindow.cpp" line="109"/>
        <location filename="../lyricswindow.cpp" line="117"/>
        <location filename="../lyricswindow.cpp" line="125"/>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="130"/>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Not found</source>
        <translation>Nie znaleziono</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="151"/>
        <location filename="../lyricswindow.cpp" line="178"/>
        <source>Receiving</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="179"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Teksty: %1 - %2</translation>
    </message>
</context>
</TS>
